# GEneral PREprocessing Framework (gepref)
---

`gepref` is a minimal framework for building machine learning preprocessing strategies for different types of data (texts, images, tables, among others) using several backends.

To install `gepref`:

```sh
pip install gepref
```
